 /*--------------------------------------------------------------
  * Copyright (C), 2014
  * SAS Institute Inc., Cary, NC, USA.  All Rights Reserved
  *
  * NAME:      rd_cfds_index.sas
  * PURPOSE:   Build index for scenario-based cash flow data set
  * USAGE:     
  * PARAMETERS:
  *    RD_CFDS_INCFDSLIB : Location of data set to index
  *    RD_CFDS_INCFDS    : Data set to index
  *-------------------------------------------------------------*/

%macro rd_cfds_index_clear(rd_cfds_incfdslib, rd_cfds_incfds);
   %let RD_CFINDEX_COUNT = 0;
   proc contents data=tmpscen out=_rd_cfindex_count(keep=idxcount) noprint;
   run;
   data _null_;
      set _rd_cfindex_count(obs = 1);
      if (idxcount ge 1) then call symput('RD_CFINDEX_COUNT', '1');
   run;
   %if &RD_CFINDEX_COUNT = 1 %then %do;
   proc datasets lib=&rd_cfds_incfdslib nolist noprint nowarn;
      modify &rd_cfds_incfds;
      index delete _all_;
      run;
   quit;
   %end;
%mend;

%macro rd_cfds_index_vars(rd_cfds_varname);
   %let RD_CFINDEX_FOUNDVAR = 0;
   data _rd_cfindex_singvar;
      set _rd_fcds_vars;
      keep name;
      if (upcase(name) eq &rd_cfds_varname) then do;
      call symput('RD_CFINDEX_FOUNDVAR', '1');
      output;
      end;
   run;
   %if &RD_CFINDEX_FOUNDVAR = 1 %then %do;
      proc append base=_rd_cfindex_vars data=_rd_cfindex_singvar;
      run;
   %end;
%mend;

%macro rd_cfds_index(rd_cfds_incfdslib, rd_cfds_incfds);

proc datasets lib=work nolist noprint nowarn;
   delete _rd_cfindex_vars;
run;

proc contents data=&rd_cfds_incfdslib..&rd_cfds_incfds noprint out=_rd_fcds_vars;
run;

* this variable order is significant, do not reorder the calls;
%rd_cfds_index_vars('ANALYSISNAME');
%rd_cfds_index_vars('INSTID');
%rd_cfds_index_vars('SIMULATIONREPLICATION');
%rd_cfds_index_vars('SIMULATIONTIME');
%rd_cfds_index_vars('SIMULATIONCASE');

* remove existing indexes;
%rd_cfds_index_clear(&rd_cfds_incfdslib, &rd_cfds_incfds);

proc sql noprint;
   select * into :rd_cfindex_varlist separated by ' ' from _rd_cfindex_vars;
quit;

proc datasets lib=&rd_cfds_incfdslib noprint;
   modify &rd_cfds_incfds;
   index create scencfIdx = (&rd_cfindex_varlist);
   run;
quit;
%mend;
